# Contributing

We are very happy about all kinds of contributions. Thanks for considering to
help us out! The simplest way of contributing is to give feedback on the
project, either via creating an issue here on GitHub or by sending a message to
a maintainer. You can also report bugs that you may have found in this manner.

If you want to do more, we are also happy about pull requests. Please make sure
that you have read the [Developer Guide](DEVELOPER.md) before you start working
on a pull request.

Before joining the community, please also make sure that you agree with our
[Code of Conduct](CODE_OF_CONDUCT.md) and our [License](LICENSE).
